<?php
/*
  cod_table_yamato.php
  2004/12/2
ǽ

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/
//  ޥȱ͢
  define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_TITLE', 'ޥȥ쥯ȥӥ');
  define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_DESCRIPTION', 'ʧ(ޥȱ͢)');
  define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_PROCESS', '۶ȼԤʤϤȤˡʤȰդˤ򤪻ʧ');
  define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_FEE', ':');
  define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_OVERFLOW_ERROR', '㤤夲ۤ¤Ķᤪ갷Ǥޤ');
  define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_MAILFOOTER',
  'ʤˡޤˤ' . "\n"
. 'ãˤʧ');
?>